@@ -205,7 +205,7 @@ def parse_args():
         metavar="<file_path>",
         type=argparse.FileType("rt"),
         default=None,
-        help="Attempts to replace genome accessions in the outputs with a replacement string. Requires a two-column map file formatted like so: 'genome file accession' <tab> 'replacement string'",
+        help="Attempts to replace genome accessions in the outputs with a replacement string. Requires a two-column map file formatted like so: 'genome file accession' <tab> 'replacement string'. The replacement will automatically be cut to a maximum of 30 chars.",
     )
 
     r_group = parser.add_argument_group("optional arguments (run)")
@@ -435,6 +435,7 @@ class Genome:
 
         filter1 = self.feature_df["class"] == "protein_coding"
         filter2 = self.feature_df["genomic_accession"] == center_genomic_accession
+
         df = self.feature_df[filter1 & filter2]
 
         c = df.index.get_loc(center.name)
@@ -457,6 +458,47 @@ class Genome:
 
         return upstream + [center.name] + downstream
 
+
+    # def getTextRepresentation(self, basket_list):
+    #
+    #     from collections import OrderedDict
+    #
+    #     basket_list = OrderedDict()
+    #
+    #     basket_list[0] = ["|"]
+    #
+    #     for pos in extension_mask:
+    #
+    #         for ga in self.contigs:
+    #             df = self.feature_df[self.feature_df["genomic_accession"] == ga]
+    #
+    #             df = df[df["class"] == "protein_coding"]
+    #             df.index = range(1, len(df) + 1)
+    #
+    #             current_pos = 0
+    #             ogpos = 0
+    #
+    #             for ogpos in df["OG"].dropna().index:
+    #                 if df.loc[ogpos]["strand"] == "-":
+    #                     ogstring = "<" + df.loc[ogpos]["OG"]
+    #                 elif df.loc[ogpos]["strand"] == "+":
+    #                     ogstring = df.loc[ogpos]["OG"].replace(".fa", "") + ">"
+    #                 else:
+    #                     ogstring = "?" + df.loc[ogpos]["OG"].replace(".fa", "") + "?"
+    #
+    #                     num_of_intermdiates = ogpos - (current_pos + 1)
+    #                 if num_of_intermdiates:
+    #                     basket_list.append(decorIntermedNum(num_of_intermdiates))
+    #                 if df.loc[ogpos]["window_position"] < 0:
+    #
+    #             if len(df) > 0 and ogpos <= len(df):
+    #                 num_of_intermdiates = len(df) - ogpos
+    #                 if num_of_intermdiates:
+    #                     basket_list.append(decorIntermedNum(num_of_intermdiates))
+    #                 basket_list.append(bg.YELLOW + fg.BLACK + "|" + Style.RESET_ALL)
+    #                 if ogpos == 0:
+    #                     del basket_list[-2:]
+
     def produceCMDLOutput(self, label_map=None):
 
         colorinit()
@@ -504,9 +546,14 @@ class Genome:
                 if ogpos == 0:
                     del basket_list[-2:]
 
-        if label_map:
+        if label_map: ## currently: replace and cut the label to be exactly 30 characters long
+            label_with_blanks = label_map[self.name] + 40* " "
+            cut_label = label_with_blanks[0:30]
+            if len(cut_label[30:].replace(' ','')) != 0:
+                cut_label = cut_label[0:28] + '..'
             return (
-                self.name + "\t" + label_map[self.name] + "\t" + " ".join(basket_list)
+                #self.name + "\t" + label_map[self.name] + "\t" + " ".join(basket_list)
+                cut_label + "\t" + " ".join(basket_list)
             )
         else:
             return self.name + "\t" + " ".join(basket_list)
@@ -671,7 +718,7 @@ def parseGFF3(gff3_path):
         comment="#",
     )
 
-    ft_df = ft_df[~ft_df["feature"].isin(["exon", "transcript", "mRNA"])]
+    ft_df = ft_df[~ft_df["feature"].isin(["exon", "transcript", "mRNA"])] #filtering out irrelevant lines
 
     for cname, attrid in [
         ("product_accession", "Name"),
@@ -807,7 +854,10 @@ def compare_taxon(t, window_ogs, ogtable, center, extension_mask, label_map):
     g = profile_genome(t, window_ogs, ogtable, center, extension_mask)
     if g:
         # runprofile.enable()
+        #TODO: Represent in columns, seperate text output from visualization
+        #number_of_cols = len(extension_mask)*3  + len(extension_mask)-1+2
         str_out = g.produceCMDLOutput(label_map=label_map)
+
         # res = fg.WHITE + bg.BLACK + "IHateThis" + Style.RESET_ALL
         # runprofile.disable()
         # stats = pstats.Stats(runprofile).sort_stats('cumtime')
@@ -949,7 +999,7 @@ def main():
 
     if not any(window_ogs):
         logging.critical(
-            "No OGs found in window. Aborting. tablular OG file correctly formatted?"
+            "No OGs found in window. Aborting. Tablular OG file correctly formatted?"
             + "\n"
             + " Changing it requires deleting *.pickle from output directory to force reparsing."
         )
